@@ -4,6 +4,10 @@ use base 'DBIx::Class::ResultSet';
 use strict;
 use warnings FATAL => 'all';
 
+__PACKAGE__->load_components(qw/
+  +App::Netdisco::DB::ExplicitLocking
+/);
+
 my $search_attr = {
     order_by => {'-desc' => 'time_last'},
     '+columns' => [
@@ -14,6 +18,29 @@ my $search_attr = {
     join => 'oui'
 };
 
+=head1 with_times
+
+This is a modifier for any C<search()> (including the helpers below) which
+will add the following additional synthesized columns to the result set:
+
+=over 4
+
+=item time_first_stamp
+
+=item time_last_stamp
+
+=back
+
+=cut
+
+sub with_times {
+  my ($rs, $cond, $attrs) = @_;
+
+  return $rs
+    ->search_rs({}, $search_attr)
+    ->search($cond, $attrs);
+}
+
 =head1 search_by_ip( \%cond, \%attrs? )
 
  my $set = $rs->search_by_ip({ip => '192.0.2.1', active => 1});
@@ -27,8 +54,8 @@ NodeIp table.
 
 The C<cond> parameter must be a hashref containing a key C<ip> with the value
 to search for. Value can either be a simple string of IPv4 or IPv6, or a
-NetAddr::IP object in which case all results within the CIDR/Prefix will be
-retrieved.
+L<NetAddr::IP::Lite> object in which case all results within the CIDR/Prefix
+will be retrieved.
 
 =item *
 
