@@ -3,6 +3,7 @@ package App::Netdisco::Web::Plugin::Search::Node;
 use Dancer ':syntax';
 use Dancer::Plugin::Ajax;
 use Dancer::Plugin::DBIC;
+use Dancer::Plugin::Auth::Extensible;
 
 use NetAddr::IP::Lite ':lower';
 use Net::MAC ();
@@ -12,7 +13,7 @@ use App::Netdisco::Web::Plugin;
 register_search_tab({ tag => 'node', label => 'Node' });
 
 # nodes matching the param as an IP or DNS hostname or MAC
-ajax '/ajax/content/search/node' => sub {
+ajax '/ajax/content/search/node' => require_login sub {
     my $node = param('q');
     send_error('Missing node', 400) unless $node;
     content_type('text/html');
@@ -58,8 +59,21 @@ ajax '/ajax/content/search/node' => sub {
             }
             $set = schema('netdisco')->resultset('NodeIp')
               ->search_by_dns({dns => $node, @active});
+
+            # if the user selects Vendor search opt, then
+            # we'll try the OUI company name as a fallback
+            if (not $set->count and param('show_vendor')) {
+                $node = param('q');
+                $set = schema('netdisco')->resultset('NodeIp')
+                  ->with_times
+                  ->search(
+                    {'oui.company' => { -ilike => "\%$node\%"}},
+                    {'prefetch' => 'oui'},
+                  );
+            }
         }
         return unless $set and $set->count;
+        $set = $set->search_rs({}, { order_by => 'me.mac' });
 
         template 'ajax/search/node_by_ip.tt', {
           macs => $set,
